@@ -20,8 +20,8 @@
 static void test_chain_maker() {
 
     auto chain = tlx::FunctionChain<>()
-                 &[](const int& d) { return d + 1; }
-                 &[](const int& d) { return d * 2; };
+                 & ([](const int& d) { return d + 1; })
+                 & ([](const int& d) { return d * 2; });
 
     // directly call function chain
     die_unequal(chain(5), (5 + 1) * 2);
@@ -36,10 +36,10 @@ static void test_empty_chain_add() {
     auto chain = tlx::make_function_chain();
     die_unequal(chain(5), 5);
 
-    auto chain2 = chain &[](const int& d) { return std::to_string(d); };
+    auto chain2 = chain & ([](const int& d) { return std::to_string(d); });
     die_unequal(chain2(5), "5");
 
-    auto chain3 = chain2 &[](const std::string& d) { return d + "2"; };
+    auto chain3 = chain2 & ([](const std::string& d) { return d + "2"; });
     die_unequal(chain3(5), "52");
 }
 
