@@ -4,7 +4,7 @@
  * Implementations of a StringSet concept. This is an internal implementation
  * header, see tlx/sort/strings.hpp for public front-end functions.
  *
- * A StringSet abstracts from arrays of strings, we provide six abstractions:
+ * A StringSet abstracts from arrays of strings, we provide four abstractions:
  *
  * - UCharStringSet: (const) unsigned char**
  * - StdStringSet: std::string*
@@ -13,7 +13,7 @@
  *
  * Part of tlx - http://panthema.net/tlx
  *
- * Copyright (C) 2015-2018 Timo Bingmann <tb@panthema.net>
+ * Copyright (C) 2015-2019 Timo Bingmann <tb@panthema.net>
  *
  * All rights reserved. Published under the Boost Software License, Version 1.0
  ******************************************************************************/
@@ -30,8 +30,13 @@
 
 #include <tlx/logger/core.hpp>
 #include <tlx/math/bswap.hpp>
+#include <tlx/meta/enable_if.hpp>
 
 namespace tlx {
+
+//! \addtogroup tlx_sort
+//! \{
+
 namespace sort_strings_detail {
 
 /******************************************************************************/
@@ -43,6 +48,12 @@ template <typename StringSet, typename Traits>
 class StringSetBase
 {
 public:
+    //! index-based array access (readable and writable) to String objects.
+    typename Traits::String& at(size_t i) const {
+        const StringSet& ss = *static_cast<const StringSet*>(this);
+        return *(ss.begin() + i);
+    }
+
     //! \name CharIterator Comparisons
     //! \{
 
@@ -55,6 +66,16 @@ public:
         return !ss.is_end(a, ai) && !ss.is_end(b, bi) && (*ai == *bi);
     }
 
+    //! check if string a is less or equal to string b at iterators ai and bi.
+    bool is_less(const typename Traits::String& a,
+                 const typename Traits::CharIterator& ai,
+                 const typename Traits::String& b,
+                 const typename Traits::CharIterator& bi) const {
+        const StringSet& ss = *static_cast<const StringSet*>(this);
+        return ss.is_end(a, ai) ||
+               (!ss.is_end(a, ai) && !ss.is_end(b, bi) && *ai < *bi);
+    }
+
     //! check if string a is less or equal to string b at iterators ai and bi.
     bool is_leq(const typename Traits::String& a,
                 const typename Traits::CharIterator& ai,
@@ -101,6 +122,60 @@ public:
         return v;
     }
 
+    //! Return up to 4 characters of string s at iterator i packed into a
+    //! uint32_t (only works correctly for 8-bit characters)
+    uint32_t get_uint32(
+        const typename Traits::String& s, typename Traits::CharIterator i) const {
+        const StringSet& ss = *static_cast<const StringSet*>(this);
+
+        uint32_t v = 0;
+        if (ss.is_end(s, i)) return v;
+        v = (uint32_t(*i) << 24);
+        ++i;
+        if (ss.is_end(s, i)) return v;
+        v |= (uint32_t(*i) << 16);
+        ++i;
+        if (ss.is_end(s, i)) return v;
+        v |= (uint32_t(*i) << 8);
+        ++i;
+        if (ss.is_end(s, i)) return v;
+        v |= (uint32_t(*i) << 0);
+        return v;
+    }
+
+    //! Return up to 8 characters of string s at iterator i packed into a
+    //! uint64_t (only works correctly for 8-bit characters)
+    uint64_t get_uint64(
+        const typename Traits::String& s, typename Traits::CharIterator i) const {
+        const StringSet& ss = *static_cast<const StringSet*>(this);
+
+        uint64_t v = 0;
+        if (ss.is_end(s, i)) return v;
+        v = (uint64_t(*i) << 56);
+        ++i;
+        if (ss.is_end(s, i)) return v;
+        v |= (uint64_t(*i) << 48);
+        ++i;
+        if (ss.is_end(s, i)) return v;
+        v |= (uint64_t(*i) << 40);
+        ++i;
+        if (ss.is_end(s, i)) return v;
+        v |= (uint64_t(*i) << 32);
+        ++i;
+        if (ss.is_end(s, i)) return v;
+        v |= (uint64_t(*i) << 24);
+        ++i;
+        if (ss.is_end(s, i)) return v;
+        v |= (uint64_t(*i) << 16);
+        ++i;
+        if (ss.is_end(s, i)) return v;
+        v |= (uint64_t(*i) << 8);
+        ++i;
+        if (ss.is_end(s, i)) return v;
+        v |= (uint64_t(*i) << 0);
+        return v;
+    }
+
     uint8_t get_uint8(const typename Traits::String& s, size_t depth) const {
         const StringSet& ss = *static_cast<const StringSet*>(this);
         return get_uint8(s, ss.get_chars(s, depth));
@@ -111,6 +186,16 @@ public:
         return get_uint16(s, ss.get_chars(s, depth));
     }
 
+    uint32_t get_uint32(const typename Traits::String& s, size_t depth) const {
+        const StringSet& ss = *static_cast<const StringSet*>(this);
+        return get_uint32(s, ss.get_chars(s, depth));
+    }
+
+    uint64_t get_uint64(const typename Traits::String& s, size_t depth) const {
+        const StringSet& ss = *static_cast<const StringSet*>(this);
+        return get_uint64(s, ss.get_chars(s, depth));
+    }
+
     //! \}
 
     //! Subset this string set using index range.
@@ -135,10 +220,10 @@ public:
     bool check_order() const {
         const StringSet& ss = *static_cast<const StringSet*>(this);
 
-        for (typename Traits::Iterator pi = ss.begin() + 1;
-             pi != ss.end(); ++pi)
+        for (typename Traits::Iterator pi = ss.begin();
+             pi + 1 != ss.end(); ++pi)
         {
-            if (!check_order(ss[pi - 1], ss[pi])) {
+            if (!check_order(*pi, *(pi + 1))) {
                 TLX_LOG1 << "check_order() failed at position " << pi - ss.begin();
                 return false;
             }
@@ -157,6 +242,28 @@ public:
     }
 };
 
+template <typename Type, typename StringSet>
+inline
+typename enable_if<sizeof(Type) == 4, uint32_t>::type
+get_key(const StringSet& strset,
+        const typename StringSet::String& s, size_t depth) {
+    return strset.get_uint32(s, depth);
+}
+
+template <typename Type, typename StringSet>
+inline
+typename enable_if<sizeof(Type) == 8, uint64_t>::type
+get_key(const StringSet& strset,
+        const typename StringSet::String& s, size_t depth) {
+    return strset.get_uint64(s, depth);
+}
+
+template <typename Type, typename StringSet>
+inline
+Type get_key_at(const StringSet& strset, size_t idx, size_t depth) {
+    return get_key<Type>(strset, strset.at(idx), depth);
+}
+
 /******************************************************************************/
 
 /*!
@@ -537,70 +644,10 @@ protected:
 
 /******************************************************************************/
 
-//! Objectified string array pointer and shadow pointer array for out-of-place
-//! swapping of pointers.
-template <typename StringSet_>
-class StringShadowPtr
-{
-public:
-    typedef StringSet_ StringSet;
-    typedef typename StringSet::String String;
-    typedef typename StringSet::Iterator Iterator;
-
-protected:
-    //! strings (front) and temporary shadow (back) array
-    StringSet active_, shadow_;
-
-    //! false if active_ is original, true if shadow_ is original
-    bool flipped_;
-
-public:
-    //! constructor specifying all attributes
-    StringShadowPtr(const StringSet& original, const StringSet& shadow,
-                    bool flipped = false)
-        : active_(original), shadow_(shadow), flipped_(flipped)
-    { }
-
-    //! return currently active array
-    const StringSet& active() const { return active_; }
-
-    //! return current shadow array
-    const StringSet& shadow() const { return shadow_; }
-
-    //! true if flipped to back array
-    bool flipped() const { return flipped_; }
-
-    //! return valid length
-    size_t size() const { return active_.size(); }
-
-    //! construct a StringShadowPtr object specifying a sub-array with flipping
-    //! to other array.
-    StringShadowPtr flip(size_t begin, size_t end) const {
-        assert(end <= size());
-        return StringShadowPtr(shadow_.subi(begin, end),
-                               active_.subi(begin, end), !flipped_);
-    }
-
-    //! construct a StringShadowPtr object specifying a sub-array with flipping
-    //! to other array.
-    StringShadowPtr flip() const {
-        return StringShadowPtr(shadow_, active_, !flipped_);
-    }
-
-    //! return subarray pointer to n strings in original array, might copy from
-    //! shadow before returning.
-    const StringSet& copy_back() const {
-        if (!flipped_) {
-            return active_;
-        }
-        else {
-            std::move(active_.begin(), active_.end(), shadow_.begin());
-            return shadow_;
-        }
-    }
-};
-
 } // namespace sort_strings_detail
+
+//! \}
+
 } // namespace tlx
 
 #endif // !TLX_SORT_STRINGS_STRING_SET_HEADER
