@@ -1,3 +1,4 @@
+// no-networkit-format
 /*
  * QuadNodePolarEuclid.hpp
  *
@@ -391,7 +392,6 @@ public:
                     if (i >= lsize) break;
                     TRACE("Jumped with delta ", delta, " arrived at ", i);
                 }
-                assert(i >= 0);
 
                 //see where we've arrived
                 candidatesTested++;
