@@ -1,3 +1,4 @@
+// no-networkit-format
 /*
  * Cover.hpp
  *
@@ -43,10 +44,6 @@ public:
      */
     Cover(const Partition &p);
 
-    /** Default destructor */
-    virtual ~Cover() = default;
-
-
     /**
      *  Index operator.
      *
