@@ -1,3 +1,4 @@
+// no-networkit-format
 /*
  * ChungLu.cpp
  *
@@ -54,7 +55,7 @@ ChungLuGenerator::ChungLuGenerator(const std::vector<count> &degreeSequence) :
             }
         }
 
-        return gB.toGraph(true,true);
+        return gB.completeGraph(true);
     }
 
 } /* namespace NetworKit */
