@@ -7,8 +7,6 @@
  *              Marvin Ritter <marvin.ritter@gmail.com>
  */
 
-// networkit-format
-
 #include <cmath>
 #include <map>
 #include <random>
@@ -22,12 +20,12 @@ namespace NetworKit {
 
 /** CONSTRUCTORS **/
 
-Graph::Graph(count n, bool weighted, bool directed)
+Graph::Graph(count n, bool weighted, bool directed, bool edgesIndexed)
     : n(n), m(0), storedNumberOfSelfLoops(0), z(n), omega(0), t(0),
 
-      weighted(weighted),  // indicates whether the graph is weighted or not
-      directed(directed),  // indicates whether the graph is directed or not
-      edgesIndexed(false), // edges are not indexed by default
+      weighted(weighted),         // indicates whether the graph is weighted or not
+      directed(directed),         // indicates whether the graph is directed or not
+      edgesIndexed(edgesIndexed), // edges are not indexed by default
 
       exists(n, true),
 
@@ -58,14 +56,14 @@ Graph::Graph(std::initializer_list<WeightedEdge> edges) : Graph(0, true) {
     }
 }
 
-Graph::Graph(const Graph &G, bool weighted, bool directed)
-    : n(G.n), m(G.m), storedNumberOfSelfLoops(G.storedNumberOfSelfLoops), z(G.z), omega(0), t(G.t),
-      weighted(weighted), directed(directed),
-      edgesIndexed(false), // edges are not indexed by default
+Graph::Graph(const Graph &G, bool weighted, bool directed, bool edgesIndexed)
+    : n(G.n), m(G.m), storedNumberOfSelfLoops(G.storedNumberOfSelfLoops), z(G.z),
+      omega(edgesIndexed ? G.omega : 0), t(G.t), weighted(weighted), directed(directed),
+      edgesIndexed(edgesIndexed), // edges are not indexed by default
       exists(G.exists),
 
       // let the following be empty for the start, we fill them later
-      inEdges(0), outEdges(0), inEdgeWeights(0), outEdgeWeights(0) {
+      inEdges(0), outEdges(0), inEdgeWeights(0), outEdgeWeights(0), inEdgeIds(0), outEdgeIds(0) {
 
     if (G.isDirected() == directed) {
         // G.inEdges might be empty (if G is undirected), but
@@ -97,6 +95,10 @@ Graph::Graph(const Graph &G, bool weighted, bool directed)
                 }
             }
         }
+        if (G.hasEdgeIds() && edgesIndexed) {
+            inEdgeIds = G.inEdgeIds;
+            outEdgeIds = G.outEdgeIds;
+        }
     } else if (G.isDirected()) {
         // G is directed, but we want an undirected graph
         // so we need to combine the out and in stuff for every node
@@ -129,6 +131,17 @@ Graph::Graph(const Graph &G, bool weighted, bool directed)
                 }
             }
         }
+        if (G.hasEdgeIds() && edgesIndexed) {
+            for (node u = 0; u < z; u++) {
+
+                // copy both out and in edges ids into our new outEdgesIds
+                outEdgeIds[u].reserve(G.outEdgeIds[u].size() + G.inEdgeIds[u].size());
+                outEdgeIds[u].insert(outEdgeIds[u].end(), G.outEdgeIds[u].begin(),
+                                     G.outEdgeIds[u].end());
+                outEdgeIds[u].insert(outEdgeIds[u].end(), G.inEdgeIds[u].begin(),
+                                     G.inEdgeIds[u].end());
+            }
+        }
     } else {
         // G is not directed, but this copy should be
         // generally we can can copy G.out stuff into our in stuff
@@ -153,7 +166,14 @@ Graph::Graph(const Graph &G, bool weighted, bool directed)
                 }
             }
         }
+        if (G.hasEdgeIds() && edgesIndexed) {
+            inEdgeIds = G.outEdgeIds;
+            outEdgeIds = G.outEdgeIds;
+        }
     }
+
+    if (!G.edgesIndexed && edgesIndexed)
+        indexEdges();
 }
 
 void Graph::preallocateUndirected(node u, size_t size) {
@@ -169,18 +189,33 @@ void Graph::preallocateUndirected(node u, size_t size) {
 }
 
 void Graph::preallocateDirected(node u, size_t outSize, size_t inSize) {
+    preallocateDirectedOutEdges(u, outSize);
+    preallocateDirectedInEdges(u, inSize);
+}
+
+void Graph::preallocateDirectedOutEdges(node u, size_t outSize) {
     assert(directed);
     assert(exists[u]);
-    inEdges[u].reserve(inSize);
     outEdges[u].reserve(outSize);
 
     if (weighted) {
-        inEdgeWeights[u].reserve(inSize);
         outEdgeWeights[u].reserve(outSize);
     }
+    if (edgesIndexed) {
+        outEdges[u].reserve(outSize);
+    }
+}
+
+void Graph::preallocateDirectedInEdges(node u, size_t inSize) {
+    assert(directed);
+    assert(exists[u]);
+    inEdges[u].reserve(inSize);
+
+    if (weighted) {
+        inEdgeWeights[u].reserve(inSize);
+    }
     if (edgesIndexed) {
         inEdgeIds[u].reserve(inSize);
-        outEdgeIds[u].reserve(outSize);
     }
 }
 /** PRIVATE HELPERS **/
@@ -269,12 +304,12 @@ edgeid Graph::edgeId(node u, node v) const {
     if (!edgesIndexed) {
         throw std::runtime_error("edges have not been indexed - call indexEdges first");
     }
+
     index i = indexInOutEdgeArray(u, v);
 
     if (i == none) {
         throw std::runtime_error("Edge does not exist");
     }
-
     edgeid id = outEdgeIds[u][i];
     return id;
 }
@@ -855,6 +890,10 @@ void Graph::increaseWeight(node u, node v, edgeweight ew) {
     }
 }
 
+void Graph::setWeightAtIthNeighbor(Unsafe, node u, index i, edgeweight ew) {
+    outEdgeWeights[u][i] = ew;
+}
+
 /** SUMS **/
 
 edgeweight Graph::totalEdgeWeight() const noexcept {
@@ -882,7 +921,65 @@ bool Graph::checkConsistency() const {
         });
     });
 
-    return noMultiEdges;
+    bool correctNodeUpperbound = (z == outEdges.size()) && ((directed ? z : 0) == inEdges.size())
+                                 && ((weighted ? z : 0) == outEdgeWeights.size())
+                                 && ((weighted && directed ? z : 0) == inEdgeWeights.size())
+                                 && ((edgesIndexed ? z : 0) == outEdgeIds.size())
+                                 && ((edgesIndexed && directed ? z : 0) == inEdgeIds.size());
+
+    if (!correctNodeUpperbound)
+        DEBUG("Saved node upper bound doesn't actually match the actual node upper bound!");
+
+    count NumberOfOutEdges = 0;
+    count NumberOfOutEdgeWeights = 0;
+    count NumberOfOutEdgeIds = 0;
+    for (index i = 0; i < outEdges.size(); i++) {
+        NumberOfOutEdges += outEdges[i].size();
+    }
+    if (weighted)
+        for (index i = 0; i < outEdgeWeights.size(); i++) {
+            NumberOfOutEdgeWeights += outEdgeWeights[i].size();
+        }
+    if (edgesIndexed)
+        for (index i = 0; i < outEdgeIds.size(); i++) {
+            NumberOfOutEdgeIds += outEdgeIds[i].size();
+        }
+
+    count NumberOfInEdges = 0;
+    count NumberOfInEdgeWeights = 0;
+    count NumberOfInEdgeIds = 0;
+    if (directed) {
+        for (index i = 0; i < inEdges.size(); i++) {
+            NumberOfInEdges += inEdges[i].size();
+        }
+        if (weighted)
+            for (index i = 0; i < inEdgeWeights.size(); i++) {
+                NumberOfInEdgeWeights += inEdgeWeights[i].size();
+            }
+        if (edgesIndexed)
+            for (index i = 0; i < inEdgeIds.size(); i++) {
+                NumberOfInEdgeIds += inEdgeIds[i].size();
+            }
+    }
+
+    if (!directed) {
+        NumberOfOutEdges = (NumberOfOutEdges + storedNumberOfSelfLoops) / 2;
+        if (weighted)
+            NumberOfOutEdgeWeights = (NumberOfOutEdgeWeights + storedNumberOfSelfLoops) / 2;
+        if (edgesIndexed)
+            NumberOfOutEdgeIds = (NumberOfOutEdgeIds + storedNumberOfSelfLoops) / 2;
+    }
+
+    bool correctNumberOfEdges = (m == NumberOfOutEdges) && ((directed ? m : 0) == NumberOfInEdges)
+                                && ((weighted ? m : 0) == NumberOfOutEdgeWeights)
+                                && ((weighted && directed ? m : 0) == NumberOfInEdgeWeights)
+                                && ((edgesIndexed ? m : 0) == NumberOfOutEdgeIds)
+                                && ((edgesIndexed && directed ? m : 0) == NumberOfInEdgeIds);
+
+    if (!correctNumberOfEdges)
+        DEBUG("Saved number of edges is incorrect!");
+
+    return noMultiEdges && correctNodeUpperbound && correctNumberOfEdges;
 }
 
 } /* namespace NetworKit */
