@@ -1,4 +1,3 @@
-// networkit-format
 
 #include <algorithm>
 
@@ -6,6 +5,7 @@
 #include <networkit/auxiliary/Random.hpp>
 #include <networkit/graph/Graph.hpp>
 #include <networkit/graph/GraphTools.hpp>
+#include <networkit/graph/TopologicalSort.hpp>
 
 namespace NetworKit {
 
@@ -505,5 +505,12 @@ void sortEdgesByWeight(Graph &G, bool decreasing) {
         });
 }
 
+std::vector<node> topologicalSort(const Graph &G) {
+    TopologicalSort topSort(G);
+    topSort.run();
+
+    return topSort.getResult();
+}
+
 } // namespace GraphTools
 } // namespace NetworKit
